# Copyrights 2001-2004-2007 by Mark Overmeer <perl@overmeer.net>.
# For other contributors see Changes.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 0.99.

use strict;
use warnings;
package A;
use vars '$VERSION';
$VERSION = '0.16';

sub a() {'a'}

1;
